#!/bin/bash
#======================================================================
# Linux shell script to launch Template Designer
# with FlexDoc/XML DiagramKit as provider of diagrams
#======================================================================

#----------------------------------------------------------------------
# Specify the absolute pathname of FlexDoc/XML home directory
# (by default, derive it from the location of this shell script file)
#----------------------------------------------------------------------
FDH=`cd "$(dirname "${BASH_SOURCE[0]}")/../.." > /dev/null && pwd`

#----------------------------------------------------------------------
# Specify the location of Java 11 (or later) here. The default setting:
#
# JAVA_HOME="$FDH/jre"
#
# assumes the installation of FlexDoc JRE (OpenJDK+JavaFX),
# which you can download from http://www.flexdoc.xyz/downloads/
#----------------------------------------------------------------------
JAVA_HOME="$FDH/jre"

#----------------------------------------------------------------------
# Specify the location of JavaFX SDK 'lib' directory, e.g.:
# /home/user/javafx-sdk-17/lib
#
# Note: When you use FlexDoc JRE, leave this setting empty
#----------------------------------------------------------------------
PATH_TO_FX= 

#----------------------------------------------------------------------
# -Xmx option sets the maximum heap size allocated by JVM.
#
# Check this option when you need to process large quantities of data!
# The JVM options below set the initial Java heap size to 1024 Mb
# and allow extending it up to 2048 Mb.
#----------------------------------------------------------------------
JAVA_OPTIONS="-Xms1024m -Xmx2048m"

#----------------------------------------------------------------------
# FlexDoc/XML module path
#----------------------------------------------------------------------
MODULE_PATH="$FDH/lib/flexdoc-xml.jar:$FDH/lib/flexdoc-xml-diagramkit.jar:$FDH/lib/xercesImpl.jar:$PATH_TO_FX"

#----------------------------------------------------------------------
# Run Template Designer.
#
# The '-flexdocconfig' option specifies the FlexDoc main configuration
# file prepared for macOS (found in '{flexdoc-xml}/bin/macOS' directory).
#
# The '-m:IMAGE_PROVIDER' option specifies FlexDoc/XML DiagramKit as Element Image Provider.
#
# Other double quotes are needed also because of possible spaces in file pathnames. 
#----------------------------------------------------------------------

"$JAVA_HOME/bin/java" $JAVA_OPTIONS --module-path "$MODULE_PATH" --module flexdoc.xml/xyz.flexdoc.xml.Designer \
    -flexdocconfig "$FDH/bin/linux/flexdoc.config" \
    -m:IMAGE_PROVIDER=DiagramKit
